@@ -37,7 +37,6 @@
 
 #include "gtksourceview-marshal.h"
 #include "gtksourceview-typebuiltins.h"
-#include "gtksourcemark.h"
 #include "gtksourceview.h"
 
 /*
@@ -86,7 +85,6 @@ enum {
 enum {
 	PROP_0,
 	PROP_SHOW_LINE_NUMBERS,
-	PROP_SHOW_LINE_MARKS,
 	PROP_TAB_WIDTH,
 	PROP_INDENT_WIDTH,
 	PROP_AUTO_INDENT,
@@ -103,7 +101,6 @@ struct _GtkSourceViewPrivate
 	guint		 tab_width;
 	gint		 indent_width;
 	gboolean 	 show_line_numbers;
-	gboolean	 show_line_marks;
 	gboolean	 auto_indent;
 	gboolean	 insert_spaces;
 	gboolean	 highlight_current_line;
@@ -117,11 +114,10 @@ struct _GtkSourceViewPrivate
 	gboolean	 style_scheme_applied;
 	GtkSourceStyleScheme *style_scheme;
 	GdkGC		*current_line_gc;
+	GHashTable 	*pixmap_cache;
 	GdkColor        *right_margin_line_color;
 	GdkColor        *right_margin_overlay_color;
 
-	GHashTable 	*mark_categories;
-
 	GtkSourceBuffer *source_buffer;
 	gint		 old_lines;
 };
@@ -141,11 +137,6 @@ static const GtkTargetEntry drop_types[] = {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-typedef struct 
-{
-	gint priority;
-	GdkPixbuf *pixbuf;
-} MarkCategory;
 
 /* Prototypes. */
 static GObject *gtk_source_view_constructor		(GType               type,
@@ -210,10 +201,6 @@ static void	gtk_source_view_realize			(GtkWidget         *widget);
 static void	gtk_source_view_unrealize		(GtkWidget         *widget);
 static void	gtk_source_view_update_style_scheme	(GtkSourceView     *view);
 
-static MarkCategory *
-		mark_category_new			(gint               priority,
-							 GdkPixbuf         *pixbuf);
-static void	mark_category_free			(MarkCategory      *cat);
 
 /* Private functions. */
 static void
@@ -245,31 +232,14 @@ gtk_source_view_class_init (GtkSourceViewClass *klass)
 
 	klass->undo = gtk_source_view_undo;
 	klass->redo = gtk_source_view_redo;
-	
-	/**
-	 * GtkSourceView:show-line-numbers:
-	 *
-	 * Whether to display line numbers
-	 */
+
 	g_object_class_install_property (object_class,
 					 PROP_SHOW_LINE_NUMBERS,
-					 g_param_spec_boolean ("show-line-numbers",
+					 g_param_spec_boolean ("show_line_numbers",
 							       _("Show Line Numbers"),
 							       _("Whether to display line numbers"),
 							       FALSE,
 							       G_PARAM_READWRITE));
-	/**
-	 * GtkSourceView:show-line-marks:
-	 *
-	 * Whether to display line mark pixbufs
-	 */
-	g_object_class_install_property (object_class,
-					 PROP_SHOW_LINE_MARKS,
-					 g_param_spec_boolean ("show-line-marks",
-							       _("Show Line Marks"),
-							       _("Whether to display line mark pixbufs"),
-							       FALSE,
-							       G_PARAM_READWRITE));
 
 	/**
 	 * GtkSourceView:tab-width:
@@ -437,11 +407,6 @@ gtk_source_view_set_property (GObject      *object,
 							       g_value_get_boolean (value));
 			break;
 
-		case PROP_SHOW_LINE_MARKS:
-			gtk_source_view_set_show_line_marks (view,
-							     g_value_get_boolean (value));
-			break;
-
 		case PROP_TAB_WIDTH:
 			gtk_source_view_set_tab_width (view,
 						       g_value_get_uint (value));
@@ -513,11 +478,6 @@ gtk_source_view_get_property (GObject    *object,
 					     gtk_source_view_get_show_line_numbers (view));
 			break;
 
-		case PROP_SHOW_LINE_MARKS:
-			g_value_set_boolean (value,
-					     gtk_source_view_get_show_line_marks (view));
-			break;
-
 		case PROP_TAB_WIDTH:
 			g_value_set_uint (value,
 					  gtk_source_view_get_tab_width (view));
@@ -572,10 +532,7 @@ gtk_source_view_get_property (GObject    *object,
 static void
 notify_buffer (GtkSourceView *view)
 {
-	/* we use view->buffer directly instead of get_buffer()
-	 * since the latter causes the buffer to be recreated and that
-	 * is not a good idea when finalizing */
-	set_source_buffer (view, GTK_TEXT_VIEW (view)->buffer);
+	set_source_buffer (view, gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 }
 
 static void
@@ -593,16 +550,16 @@ gtk_source_view_init (GtkSourceView *view)
 	view->priv->right_margin_pos = DEFAULT_RIGHT_MARGIN_POSITION;
 	view->priv->cached_right_margin_pos = -1;
 
+	view->priv->pixmap_cache = g_hash_table_new_full (g_str_hash, g_str_equal,
+							  (GDestroyNotify) g_free,
+							  (GDestroyNotify) g_object_unref);
+
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (view), 2);
 	gtk_text_view_set_right_margin (GTK_TEXT_VIEW (view), 2);
-
+	
 	view->priv->right_margin_line_color = NULL;
 	view->priv->right_margin_overlay_color = NULL;
 
-	view->priv->mark_categories = g_hash_table_new_full (g_str_hash, g_str_equal,
-							     (GDestroyNotify) g_free,
-							     (GDestroyNotify) mark_category_free);
-
 	tl = gtk_drag_dest_get_target_list (GTK_WIDGET (view));
 	g_return_if_fail (tl != NULL);
 
@@ -649,16 +606,16 @@ gtk_source_view_finalize (GObject *object)
 
 	if (view->priv->style_scheme)
 		g_object_unref (view->priv->style_scheme);
-	
+
+	if (view->priv->pixmap_cache)
+		g_hash_table_destroy (view->priv->pixmap_cache);
+
 	if (view->priv->right_margin_line_color != NULL)
 		gdk_color_free (view->priv->right_margin_line_color);
 
 	if (view->priv->right_margin_overlay_color != NULL)
 		gdk_color_free (view->priv->right_margin_overlay_color);
 
-	if (view->priv->mark_categories)
-		g_hash_table_destroy (view->priv->mark_categories);
-
 	set_source_buffer (view, NULL);
 
 	G_OBJECT_CLASS (gtk_source_view_parent_class)->finalize (object);
@@ -730,23 +687,6 @@ highlight_updated_cb (GtkSourceBuffer *buffer,
 	});
 }
 
-static void
-source_mark_updated_cb (GtkSourceBuffer *buffer,
-			GtkSourceMark	*mark,
-			GtkTextView     *text_view)
-{
-	GdkWindow *margin;
-
-	margin = gtk_text_view_get_window (text_view, GTK_TEXT_WINDOW_LEFT);
-	if (margin != NULL)
-	{
-		GdkRegion *region;
-
-		region = gdk_drawable_get_visible_region (GDK_DRAWABLE (margin));
-		gdk_window_invalidate_region (margin, region, TRUE);
-	}
-}
-
 static void
 buffer_style_scheme_changed_cb (GtkSourceBuffer *buffer,
 				GParamSpec	*pspec,
@@ -767,9 +707,6 @@ set_source_buffer (GtkSourceView *view,
 		g_signal_handlers_disconnect_by_func (view->priv->source_buffer,
 						      highlight_updated_cb,
 						      view);
-		g_signal_handlers_disconnect_by_func (view->priv->source_buffer,
-						      source_mark_updated_cb,
-						      view);
 		g_signal_handlers_disconnect_by_func (view->priv->source_buffer,
 						      buffer_style_scheme_changed_cb,
 						      view);
@@ -784,10 +721,6 @@ set_source_buffer (GtkSourceView *view,
 				  "highlight_updated",
 				  G_CALLBACK (highlight_updated_cb),
 				  view);
-		g_signal_connect (buffer,
-				  "source_mark_updated",
-				  G_CALLBACK (source_mark_updated_cb),
-				  view);
 		g_signal_connect (buffer,
 				  "notify::style-scheme",
 				  G_CALLBACK (buffer_style_scheme_changed_cb),
@@ -1063,7 +996,8 @@ gtk_source_view_get_lines (GtkTextView  *text_view,
 	gtk_text_view_get_line_at_y (text_view, &iter, first_y, NULL);
 
 	/* For each iter, get its location and add it to the arrays.
-	 * Stop when we pass last_y */
+	 * Stop when we pass last_y
+	*/
 	count = 0;
   	size = 0;
 
@@ -1105,116 +1039,6 @@ gtk_source_view_get_lines (GtkTextView  *text_view,
 	*countp = count;
 }
 
-static gint
-sort_marks_by_priority (gconstpointer m1, 
-			gconstpointer m2,
-			gpointer data)
-{
-	GtkSourceMark *mark1 = GTK_SOURCE_MARK (m1);
-	GtkSourceMark *mark2 = GTK_SOURCE_MARK (m2);
-	GtkSourceView *view = GTK_SOURCE_VIEW (data);
-	GtkTextIter iter1, iter2;
-	gint line1;
-	gint line2;
-
-	gtk_text_buffer_get_iter_at_mark (gtk_text_mark_get_buffer (GTK_TEXT_MARK (mark1)),
-					  &iter1, 
-					  GTK_TEXT_MARK (mark1));
-	gtk_text_buffer_get_iter_at_mark (gtk_text_mark_get_buffer (GTK_TEXT_MARK (mark2)),
-					  &iter2, 
-					  GTK_TEXT_MARK (mark2));
-
-	line1 = gtk_text_iter_get_line (&iter1);
-	line2 = gtk_text_iter_get_line (&iter2);
-
-	if (line1 == line2)
-	{
-		guint priority1 = gtk_source_view_get_mark_category_priority (view,
-						gtk_source_mark_get_category (mark1));
-		guint priority2 = gtk_source_view_get_mark_category_priority (view,
-						gtk_source_mark_get_category (mark2));
-
-		return priority1 - priority2;
-	}
-	else
-	{
-		return line2 - line1;
-	}
-}
-
-static void
-draw_line_marks (GtkSourceView *view,
-		 GSList        *marks,
-		 gint           x,
-		 gint           y)
-{
-	GdkPixbuf *composite;
-	gint width, height;
-
-	/* Draw the mark with higher priority */
-	marks = g_slist_sort_with_data (marks, sort_marks_by_priority, view);
-
-	composite = NULL;
-	width = height = 0;
-
-	/* composite all the pixbufs for the marks present at the line */
-	do
-	{
-		GtkSourceMark *mark;
-		GdkPixbuf *pixbuf;
-
-		mark = marks->data;
-
-		pixbuf = gtk_source_view_get_mark_category_pixbuf (view,
-					gtk_source_mark_get_category (mark));
-
-		if (pixbuf != NULL)
-		{
-			if (composite == NULL)
-			{
-				composite = gdk_pixbuf_copy (pixbuf);
-				width = gdk_pixbuf_get_width (composite);
-				height = gdk_pixbuf_get_height (composite);
-			}
-			else
-			{
-				gint pixbuf_w;
-				gint pixbuf_h;
-
-				pixbuf_w = gdk_pixbuf_get_width (pixbuf);
-				pixbuf_h = gdk_pixbuf_get_height (pixbuf);
-				gdk_pixbuf_composite (pixbuf,
-						      composite,
-						      0, 0,
-						      width, height,
-						      0, 0,
-						      (double) pixbuf_w / width,
-						      (double) pixbuf_h / height,
-						      GDK_INTERP_BILINEAR,
-						      COMPOSITE_ALPHA);
-			}
-			g_object_unref (pixbuf);
-		}
-
-		marks = g_slist_next (marks);
-	}
-	while (marks);
-
-	if (composite != NULL)
-	{
-		GdkWindow *window;
-
-		window = gtk_text_view_get_window (GTK_TEXT_VIEW (view),
-						   GTK_TEXT_WINDOW_LEFT);
-
-		gdk_draw_pixbuf (GDK_DRAWABLE (window), NULL, composite,
-				 0, 0, x, y,
-				 width, height,
-				 GDK_RGB_DITHER_NORMAL, 0, 0);
-		g_object_unref (composite);
-	}
-}
-
 static void
 gtk_source_view_paint_margin (GtkSourceView *view,
 			      GdkEventExpose *event)
@@ -1235,7 +1059,7 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 
 	text_view = GTK_TEXT_VIEW (view);
 
-	if (!view->priv->show_line_numbers && !view->priv->show_line_marks)
+	if (!view->priv->show_line_numbers)
 	{
 		gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (text_view),
 						      GTK_TEXT_WINDOW_LEFT,
@@ -1312,11 +1136,7 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 
 	x_pixmap = margin_width;
 
-	if (view->priv->show_line_marks)
-		margin_width += GUTTER_PIXMAP;
-
-	/* no line & no marks case is short circuited before */
-	g_assert (margin_width != 0);
+	g_return_if_fail (margin_width != 0);
 
 	gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (text_view),
 					      GTK_TEXT_WINDOW_LEFT,
@@ -1326,12 +1146,12 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 					  &cur,
 					  gtk_text_buffer_get_insert (text_view->buffer));
 
-	cur_line = gtk_text_iter_get_line (&cur);
+	cur_line = gtk_text_iter_get_line (&cur) + 1;
 
-	for (i = 0; i < count; ++i)
+	i = 0;
+	while (i < count)
 	{
 		gint pos;
-		gint line_to_paint;
 
 		gtk_text_view_buffer_to_window_coords (text_view,
 						       GTK_TEXT_WINDOW_LEFT,
@@ -1340,16 +1160,14 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 						       NULL,
 						       &pos);
 
-		line_to_paint = g_array_index (numbers, gint, i);
-
 		if (view->priv->show_line_numbers)
 		{
+			gint line_to_paint = g_array_index (numbers, gint, i) + 1;
+
 			if (line_to_paint == cur_line)
 			{
 				gchar *markup;
-
-				/* +1 because displayed line numbers start from 1 */
-				markup = g_strdup_printf ("<b>%d</b>", 1 + line_to_paint);
+				markup = g_strdup_printf ("<b>%d</b>", line_to_paint);
 
 				pango_layout_set_markup (layout, markup, -1);
 
@@ -1357,7 +1175,8 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 			}
 			else
 			{
-				g_snprintf (str, sizeof (str), "%d", 1 + line_to_paint);
+				g_snprintf (str, sizeof (str),
+					    "%d", line_to_paint);
 
 				pango_layout_set_markup (layout, str, -1);
 			}
@@ -1374,20 +1193,7 @@ gtk_source_view_paint_margin (GtkSourceView *view,
 					  layout);
 		}
 
-		if (view->priv->show_line_marks)
-		{
-			GSList *marks;
-
-			marks = gtk_source_buffer_get_marks_at_line (view->priv->source_buffer,
-								     line_to_paint,
-								     NULL);
-
-			if (marks != NULL)
-			{
-				/* draw marks for the line */
-				draw_line_marks (view, marks, x_pixmap, pos);
-			}
-		}
+		++i;
 	}
 
 	g_array_free (pixels, TRUE);
@@ -1736,7 +1542,7 @@ gtk_source_view_get_show_line_numbers (GtkSourceView *view)
 	g_return_val_if_fail (view != NULL, FALSE);
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->show_line_numbers != FALSE);
+	return view->priv->show_line_numbers;
 }
 
 /**
@@ -1763,12 +1569,9 @@ gtk_source_view_set_show_line_numbers (GtkSourceView *view,
 			/* Set left margin to minimum width if no margin is
 			   visible yet. Otherwise, just queue a redraw, so the
 			   expose handler will automatically adjust the margin. */
-			if (!view->priv->show_line_marks)
-				gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (view),
+			gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (view),
 								      GTK_TEXT_WINDOW_LEFT,
 								      MIN_NUMBER_WINDOW_WIDTH);
-			else
-				gtk_widget_queue_draw (GTK_WIDGET (view));
 
 			view->priv->show_line_numbers = show;
 
@@ -1789,74 +1592,6 @@ gtk_source_view_set_show_line_numbers (GtkSourceView *view,
 	}
 }
 
-/**
- * gtk_source_view_get_show_line_marks:
- * @view: a #GtkSourceView.
- *
- * Returns whether line marks are displayed beside the text.
- *
- * Return value: %TRUE if the line marks are displayed.
- *
- * Since: 2.2
- **/
-gboolean
-gtk_source_view_get_show_line_marks (GtkSourceView *view)
-{
-	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
-
-	return (view->priv->show_line_marks != FALSE);
-}
-
-/**
- * gtk_source_view_set_show_line_marks:
- * @view: a #GtkSourceView.
- * @show: whether line marks should be displayed.
- *
- * If %TRUE line marks will be displayed beside the text.
- *
- * Since: 2.2
- **/
-void
-gtk_source_view_set_show_line_marks (GtkSourceView *view,
-				     gboolean       show)
-{
-	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
-
-	show = (show != FALSE);
-
-	if (show)
-	{
-		if (!view->priv->show_line_marks)
-		{
-			/* Set left margin to minimum width if no margin is
-			   visible yet. Otherwise, just queue a redraw, so the
-			   expose handler will automatically adjust the margin. */
-			if (!view->priv->show_line_numbers)
-				gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (view),
-								      GTK_TEXT_WINDOW_LEFT,
-								      MIN_NUMBER_WINDOW_WIDTH);
-			else
-				gtk_widget_queue_draw (GTK_WIDGET (view));
-
-			view->priv->show_line_marks = show;
-
-			g_object_notify (G_OBJECT (view), "show-line-marks");
-		}
-	}
-	else
-	{
-		if (view->priv->show_line_marks)
-		{
-			view->priv->show_line_marks = show;
-
-			/* force expose event, which will adjust margin. */
-			gtk_widget_queue_draw (GTK_WIDGET (view));
-
-			g_object_notify (G_OBJECT (view), "show-line-marks");
-		}
-	}
-}
-
 static gboolean
 set_tab_stops_internal (GtkSourceView *view)
 {
@@ -1924,7 +1659,8 @@ gtk_source_view_set_tab_width (GtkSourceView *view,
 guint
 gtk_source_view_get_tab_width (GtkSourceView *view)
 {
-	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), DEFAULT_TAB_WIDTH);
+	g_return_val_if_fail (view != NULL, FALSE);
+	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
 	return view->priv->tab_width;
 }
@@ -1969,193 +1705,6 @@ gtk_source_view_get_indent_width (GtkSourceView *view)
 	return view->priv->indent_width;
 }
 
-static MarkCategory *
-mark_category_new (gint priority, GdkPixbuf *pixbuf)
-{
-	MarkCategory *cat;
-
-	cat = g_slice_new0 (MarkCategory);
-	cat->priority = priority;
-	if (pixbuf != NULL)
-		cat->pixbuf = g_object_ref (pixbuf);
-	else
-		cat->pixbuf = NULL;
-
-	return cat;
-}
-
-static void
-mark_category_free (MarkCategory *cat)
-{
-	if (cat->pixbuf)
-		g_object_unref (cat->pixbuf);
-	g_slice_free (MarkCategory, cat);
-}
-
-/**
- * gtk_source_view_set_mark_category_pixbuf:
- * @view: a #GtkSourceView.
- * @category: a mark category.
- * @pixbuf: a #GdkPixbuf or #NULL.
- *
- * Associates a given @pixbuf with a given mark @category.
- * If @pixbuf is #NULL, the pixbuf is unset.
- *
- * Since: 2.2
- */
-void
-gtk_source_view_set_mark_category_pixbuf (GtkSourceView *view,
-					  const gchar   *category,
-					  GdkPixbuf     *pixbuf)
-{
-	MarkCategory *cat;
-
-	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
-	g_return_if_fail (category != NULL);
-	g_return_if_fail (pixbuf == NULL || GDK_IS_PIXBUF (pixbuf));
-
-	cat = g_hash_table_lookup (view->priv->mark_categories, category);
-
-	if (pixbuf != NULL)
-	{
-		gint width;
-		gint height;
-
-		width = gdk_pixbuf_get_width (pixbuf);
-		height = gdk_pixbuf_get_height (pixbuf);
-		if (width > GUTTER_PIXMAP || height > GUTTER_PIXMAP)
-		{
-			if (width > GUTTER_PIXMAP)
-				width = GUTTER_PIXMAP;
-			if (height > GUTTER_PIXMAP)
-				height = GUTTER_PIXMAP;
-			pixbuf = gdk_pixbuf_scale_simple (pixbuf, width, height,
-							  GDK_INTERP_BILINEAR);
-		}
-		else
-		{
-			/* we own a reference of the pixbuf */
-			g_object_ref (pixbuf);
-		}
-
-		if (cat != NULL)
-		{
-			if (cat->pixbuf != NULL)
-				g_object_unref (cat->pixbuf);
-			cat->pixbuf = g_object_ref (pixbuf);
-		}
-		else
-		{
-			cat = mark_category_new (0, pixbuf);
-			g_hash_table_insert (view->priv->mark_categories,
-					     g_strdup (category),
-					     cat);
-		}
-
-		g_object_unref (pixbuf);
-	}
-	else
-	{
-		if (cat != NULL && cat->pixbuf != NULL)
-		{
-			g_object_unref (cat->pixbuf);
-			cat->pixbuf = NULL;
-		}
-	}
-}
-
-/**
- * gtk_source_view_get_mark_category_pixbuf:
- * @view: a #GtkSourceView.
- * @category: a mark category.
- *
- * Gets the pixbuf which is associated with the given mark @category.
- *
- * Return value: the associated #GdkPixbuf, or %NULL if not found.
- *
- * Since: 2.2
- */
-GdkPixbuf *
-gtk_source_view_get_mark_category_pixbuf (GtkSourceView *view,
-					  const gchar   *category)
-{
-	MarkCategory *cat;
-
-	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), 0);
-	g_return_val_if_fail (category != NULL, 0);
-
-	cat = g_hash_table_lookup (view->priv->mark_categories, category);
-	if (cat != NULL)
-		return g_object_ref (cat->pixbuf);
-	else
-		return NULL;
-}
-
-/**
- * gtk_source_view_set_mark_category_priority:
- * @view: a #GtkSourceView.
- * @category: a mark category.
- * @priority: the priority for the category
- *
- * Set the @priority for the given mark @category. When there are
- * multiple marks on the same line, marks of categories with
- * higher priorities will be drawn on top.
- * 
- * Since: 2.2
- */
-void
-gtk_source_view_set_mark_category_priority (GtkSourceView *view,
-					    const gchar   *category,
-					    gint          priority)
-{
-	MarkCategory *cat;
-
-	g_return_if_fail (GTK_IS_SOURCE_VIEW (view));
-	g_return_if_fail (category != NULL);
-
-	cat = g_hash_table_lookup (view->priv->mark_categories, category);
-	if (cat == NULL)
-	{
-		cat = mark_category_new (priority, NULL);
-		g_hash_table_insert (view->priv->mark_categories,
-				     g_strdup (category),
-				     cat);
-	}
-	else
-		cat->priority = priority;
-}
-
-/**
- * gtk_source_view_get_mark_category_priority:
- * @view: a #GtkSourceView.
- * @category: a mark category.
- *
- * Gets the priority which is associated with the given @category.
- *
- * Return value: the priority or if @category
- * exists but no priority was set, it defaults to 0.
- *
- * Since: 2.2
- */
-gint
-gtk_source_view_get_mark_category_priority (GtkSourceView *view,
-					    const gchar   *category)
-{
-	MarkCategory *cat;
-
-	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), 0);
-	g_return_val_if_fail (category != NULL, 0);
-
-	cat = g_hash_table_lookup (view->priv->mark_categories, category);
-	if (cat != NULL)
-		return cat->priority;
-	else
-	{
-		g_warning ("Marker Category %s does not exist!", category);
-		return 0;
-	}
-}
-
 static gchar *
 compute_indentation (GtkSourceView *view,
 		     GtkTextIter   *cur)
@@ -2739,7 +2288,7 @@ gtk_source_view_get_auto_indent (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->auto_indent != FALSE);
+	return view->priv->auto_indent;
 }
 
 /**
@@ -2779,7 +2328,7 @@ gtk_source_view_get_insert_spaces_instead_of_tabs (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->insert_spaces != FALSE);
+	return view->priv->insert_spaces;
 }
 
 /**
@@ -2822,7 +2371,7 @@ gtk_source_view_get_indent_on_tab (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->indent_on_tab != FALSE);
+	return view->priv->indent_on_tab;
 }
 
 /**
@@ -2929,7 +2478,7 @@ gtk_source_view_get_highlight_current_line (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->highlight_current_line != FALSE);
+	return view->priv->highlight_current_line;
 }
 
 /**
@@ -2969,7 +2518,7 @@ gtk_source_view_get_show_right_margin (GtkSourceView *view)
 {
 	g_return_val_if_fail (GTK_IS_SOURCE_VIEW (view), FALSE);
 
-	return (view->priv->show_right_margin != FALSE);
+	return view->priv->show_right_margin;
 }
 
 /**
@@ -3016,7 +2565,7 @@ gtk_source_view_get_right_margin_position  (GtkSourceView *view)
 /**
  * gtk_source_view_set_right_margin_position:
  * @view: a #GtkSourceView.
- * @pos: the width in characters where to position the right margin.
+ * @margin: the position of the margin to set.
  *
  * Sets the position of the right margin in the given @view.
  **/
@@ -3041,7 +2590,7 @@ gtk_source_view_set_right_margin_position (GtkSourceView *view, guint pos)
 /**
  * gtk_source_view_set_smart_home_end:
  * @view: a #GtkSourceView.
- * @smart_he: the desired behavior among #GtkSourceSmartHomeEndType.
+ * @smart_he: the desired behavior among #GtkSourceSmartHomeEndType
  *
  * Set the desired movement of the cursor when HOME and END keys
  * are pressed.
@@ -3064,10 +2613,8 @@ gtk_source_view_set_smart_home_end (GtkSourceView             *view,
  * gtk_source_view_get_smart_home_end:
  * @view: a #GtkSourceView.
  *
- * Returns a #GtkSourceSmartHomeEndType end value specifying
+ * Returns a #GtkSourceSmartHomeEndTypeend value specifying
  * how the cursor will move when HOME and END keys are pressed.
- *
- * Return value: a #GtkSourceSmartHomeEndTypeend value.
  **/
 GtkSourceSmartHomeEndType
 gtk_source_view_get_smart_home_end (GtkSourceView *view)
